<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta http-equiv="X-UA-Compatible" content="ie=edge">
        <meta name="author" content="TinyContestWinners" />
        <meta name="description" content="Create ephemeral raffles and contests. Winners are chosen at random and emailed to the contest owner" />

        <title>Tiny Contest Winners - Create fun raffles and contests!</title>
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-EVSTQN3/azprG1Anm3QDgpJLIm9Nao0Yz1ztcQTwFspd3yD65VohhpuuCOmLASjC" crossorigin="anonymous">
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.4/font/bootstrap-icons.css">
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/js/bootstrap.bundle.min.js" integrity="sha384-MrcW6ZMFYlzcLA8Nl+NtUVF0sA7MsXsP1UyJoMp4YLEuNSfAP+JcXn/tWtIaxVXM" crossorigin="anonymous"></script>
    </head>
    <body>
        <nav class="navbar navbar-expand-lg py-3 bg-white border-bottom border-info" );">
            <div class="container-fluid bg-transparent">
                <a class="navbar-brand fw-bold" href="/">Tiny Contest Winners!</a>
                <span class="small">Create fun raffles and contests</span>
            </div>
        </nav>
        <div class="container-md mt-4" style="margin-bottom: 5.0rem;">
            {% block content %}
            {% endblock content %}
        </div>
        <footer class="footer fixed-bottom" style="background: #EEE;">
            <ul class="nav justify-content-center">
                <li class=nav-item><a href="{{ url_for('contest.index') }}" class="nav-link px-2 text-muted">&copy; 2022 Tiny Contest Winners</a></li>
                <li class="nav-item"><a href="{{ url_for('contest.privacy') }}" class="nav-link px-2 text-muted">Privacy</a></li>
                <li class="nav-item"><a href="{{ url_for('contest.about') }}" class="nav-link px-2 text-muted">About</a></li>
            </ul>
        </footer>
        <script src='https://storage.ko-fi.com/cdn/scripts/overlay-widget.js'></script>
        <script>
          kofiWidgetOverlay.draw('potnanny', {
            'type': 'floating-chat',
            'floating-chat.donateButton.text': 'Support me',
            'floating-chat.donateButton.background-color': '#00b9fe',
            'floating-chat.donateButton.text-color': '#fff'
          });
        </script>
  </body>
</html>
